@@ -1,7 +1,10 @@
 #!/usr/bin/env python
 
 import sys
-from PIL import Image
+try:
+    import Image
+except ImportError:
+    from PIL import Image
 
 def crop_resize(image, size, exact_size=False):
     """
